## File Name: IRT.se.R
## File Version: 0.03


###########################################################
IRT.se <- function (object, ...)
{
	UseMethod("IRT.se")
}
###########################################################

